@@ -5,7 +5,7 @@ use strict;
 
 =head1 NAME
 
-Jaipo - 
+Jaipo - JAIku (and other micro-blogging sites) POster
 
 =head1 VERSION
 
@@ -16,8 +16,19 @@ Version 0.01
 our $VERSION = '0.01';
 
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
+Jaipo (宅噗)
+
+This project was starting for Jaiku.com, but now going to support as-much-as-we-can micro-blogging sites.
+
+"Jaiku" pronunced close to "宅窟" in Chinese, which means an area full of computer/internet users, and it really is one of the most popular sites recently. As jaiku is part of google and growing, there're still only few linux client.
+
+Jaipo is a lightweight command line Jaiku Client base on RickMeasham's Net::Jaiku perl module.
+
+Bcoz it's writen in perl, so it can run on any OS and any machine with perl. I got the first feedback that somebody use it on ARM embedded system at May 2008.
+
+Now you can read feeds, send message, and set location with Jaipo.
 
 =head1 EXPORT
 
